"use strict";
/**
 * _transform.ts
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.stringifyKVS = exports.jsonKVS = exports.transformKVS = exports.namespaceKVS = void 0;
/**
 * wrap key-value storage to prepend a prefix string for storage keys
 */
function namespaceKVS(storage, prefix) {
    return (storage === null || storage === void 0 ? void 0 : storage.delete) ? { get, set, delete: remove } : { get, set };
    function set(key, value) {
        if (prefix)
            key = prefix + key;
        return storage.set(key, value);
    }
    function get(key) {
        if (prefix)
            key = prefix + key;
        return storage.get(key);
    }
    function remove(key) {
        if (prefix)
            key = prefix + key;
        return storage.delete(key);
    }
}
exports.namespaceKVS = namespaceKVS;
/**
 * transform key-value storage to apply encode() and decode() methods
 */
function transformKVS(storage, transform) {
    return (storage === null || storage === void 0 ? void 0 : storage.delete) ? { get, set, delete: key => storage.delete(key) } : { get, set };
    async function set(key, value) {
        const encoded = transform.encode(value);
        await storage.set(key, encoded);
    }
    async function get(key) {
        const value = await storage.get(key);
        if ("undefined" === typeof value)
            return;
        return transform.decode(value);
    }
}
exports.transformKVS = transformKVS;
/**
 * transform key-value storage to encode object V to JSON string, and vice versa
 * @param storage
 */
function jsonKVS(storage) {
    return stringifyKVS(storage, JSON);
}
exports.jsonKVS = jsonKVS;
/**
 * transform key-value storage to apply stringify() and parse() methods
 */
function stringifyKVS(storage, stringifyer) {
    return transformKVS(storage, {
        encode: stringifyer.stringify,
        decode: stringifyer.parse,
    });
}
exports.stringifyKVS = stringifyKVS;
